@@ -16,7 +16,11 @@
 #include <sys/sysmacros.h>
 #endif
 #include <sys/param.h>
+#ifdef __linux__
+char *dirname(char *path);
+#else
 #include <libgen.h>
+#endif
 #include <stdlib.h>
 
 #include "ps-internal.h"
@@ -478,3 +482,13 @@ SEXP ps__mount_point(SEXP paths) {
   UNPROTECT(1);
   return res;
 }
+
+SEXP psll_memory_maxrss(SEXP p) {
+  struct rusage rusage;
+  getrusage(RUSAGE_SELF, &rusage);
+#if defined(__APPLE__)
+  return Rf_ScalarReal(rusage.ru_maxrss);
+#else
+  return Rf_ScalarReal(rusage.ru_maxrss * 1024.0);
+#endif
+}
